summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTim-Philipp Müller <tim@centricular.net>2007-02-09 09:24:58 +0000
committerTim-Philipp Müller <tim@centricular.net>2007-02-09 09:24:58 +0000
commitd8f5483d85ca53fb6b85c66352aaced527587c32 (patch)
tree26ea40f6b8ebe577fe2e71f6f00013d4a3c3d6d9
parent6bbee3202a6e6df043f3d441a2bf4dbc25aae3d4 (diff)
gst/avi/gstavimux.c: Explicitly cast result of pointer arithmetic to integer in order to avoid compiler warnings on s...
Original commit message from CVS: * gst/avi/gstavimux.c: (gst_avi_mux_riff_get_avi_header): Explicitly cast result of pointer arithmetic to integer in order to avoid compiler warnings on some 64-bit systems. Should fix #406018.
-rw-r--r--ChangeLog6
-rw-r--r--gst/avi/gstavimux.c4
2 files changed, 8 insertions, 2 deletions
diff --git a/ChangeLog b/ChangeLog
index ed971795..2ba3c7c0 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,9 @@
+2007-02-09 Tim-Philipp Müller <tim at centricular dot net>
+
+ * gst/avi/gstavimux.c: (gst_avi_mux_riff_get_avi_header):
+ Explicitly cast result of pointer arithmetic to integer in order to
+ avoid compiler warnings on some 64-bit systems. Should fix #406018.
+
2007-02-08 Tim-Philipp Müller <tim at centricular dot net>
* gst/debug/progressreport.c:
diff --git a/gst/avi/gstavimux.c b/gst/avi/gstavimux.c
index 055aba44..fddb6290 100644
--- a/gst/avi/gstavimux.c
+++ b/gst/avi/gstavimux.c
@@ -1035,7 +1035,7 @@ gst_avi_mux_riff_get_avi_header (GstAviMux * avimux)
highmark += 24;
}
- GST_WRITE_UINT32_LE (hdrl_size, buffdata - hdrl_size - 4);
+ GST_WRITE_UINT32_LE (hdrl_size, (guint32) (buffdata - hdrl_size) - 4);
/* tags */
if (tags) {
@@ -1070,7 +1070,7 @@ gst_avi_mux_riff_get_avi_header (GstAviMux * avimux)
/* finally we can fill in the RIFF size */
/* note that riff only counts the first avi chunk */
- GST_WRITE_UINT32_LE (riff_size, (buffdata - riff_size - 4) /* header and movi tags */
+ GST_WRITE_UINT32_LE (riff_size, (guint32) (buffdata - riff_size - 4) /* header and movi tags */
+avimux->idx_size + avimux->data_size - 4); /* movi data and index */
{ /* only the part that is filled in actually makes up the header